@@ -17,12 +17,12 @@ class QAbstractButton;
 namespace MailTransport
 {
 class Transport;
+class TransportActivitiesAbstractPlugin;
 
 /**
   @internal
 */
 class SMTPConfigWidgetPrivate;
-
 /**
   @internal
   Configuration widget for a SMTP transport.
@@ -41,7 +41,7 @@ public Q_SLOTS:
 private Q_SLOTS:
     void checkSmtpCapabilities();
     void passwordsLoaded();
-    void slotFinished(const QList<int> &results);
+    void slotTestFinished(const QList<int> &results);
     void hostNameChanged(const QString &text);
     void encryptionChanged(int enc);
     void ensureValidAuthSelection();
@@ -52,5 +52,6 @@ private:
 
     void init();
     void enablePasswordLine();
+    MailTransport::TransportActivitiesAbstractPlugin *mTransportActivitiesPlugin = nullptr;
 };
 } // namespace MailTransport
