@@ -5,6 +5,8 @@
 */
 
 #include "addtransportdialogng_gui.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "widgets/addtransportdialogng.h"
 
 #include <QApplication>
@@ -16,7 +18,7 @@ AddTransportDialogNG_gui::AddTransportDialogNG_gui(QWidget *parent)
     : QWidget(parent)
 {
     auto layout = new QHBoxLayout(this);
-    auto button = new QPushButton(QStringLiteral("Add transport"));
+    auto button = new QPushButton(u"Add transport"_s);
     layout->addWidget(button);
     connect(button, &QPushButton::clicked, this, [this] {
         auto dlg = new MailTransport::AddTransportDialogNG(this);
@@ -28,7 +30,7 @@ AddTransportDialogNG_gui::AddTransportDialogNG_gui(QWidget *parent)
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
-    app.setApplicationName(QStringLiteral("addtransportnewng"));
+    app.setApplicationName(u"addtransportnewng"_s);
     QStandardPaths::setTestModeEnabled(true);
     auto t = new AddTransportDialogNG_gui();
     t->show();
